plotBox: plotBox

View source: R/plot.R

plotBoxR Documentation

plotBox

Description

Draw compared boxplots of a single parameter (scalar)

Usage

plotBox(mr, x, y, ...)

Arguments

mr

Output of multiRun(), list of lists of functions results

x

Row index of the element inside the aggregated parameter

y

Column index of the element inside the aggregated parameter

...

Additional graphical parameters (xlab, ylab, ...)

Value

No return value, called for side effects.

Examples

# mr[[i]] is a list of estimated parameters matrices (here random matrices).
# Should be mr <- multiRun(...) --> see bootstrap example in ?multiRun.
simmr_path <- system.file("extdata", "simulateMr.R", package = "morpheus")
source(simmr_path)
source(simmr_path)
mr <- simulateMr(c(2,2), 10)$mr
plotBox(mr, 2, 1) #second row, first column


morpheus documentation built on May 21, 2026, 5:06 p.m.