plotCoefs: plotCoefs

View source: R/plot.R

plotCoefsR Documentation

plotCoefs

Description

Draw a graph of (averaged) coefficients estimations with their standard, deviations ordered by mean values. Note that the drawing does not correspond to a function; it is just a convenient way to visualize the estimated parameters.

Usage

plotCoefs(mr, params, ...)

Arguments

mr

List of parameters matrices

params

True value of the parameters matrix

...

Additional graphical parameters

Value

No return value, called for side effects.

Examples

# mr[[i]] is a list of estimated parameters matrices (here random matrices).
# Should be mr <- multiRun(...) --> see bootstrap example in ?multiRun.
simmr_path <- system.file("extdata", "simulateMr.R", package = "morpheus")
source(simmr_path)
mr_theta <- simulateMr(c(3,2), 10)
mr <- mr_theta$mr ; theta <- mr_theta$theta
plotCoefs(mr[[1]], theta)


morpheus documentation built on May 21, 2026, 5:06 p.m.