| plotBox | R Documentation |
Draw compared boxplots of a single parameter (scalar)
plotBox(mr, x, y, ...)
mr |
Output of multiRun(), list of lists of functions results |
x |
Row index of the element inside the aggregated parameter |
y |
Column index of the element inside the aggregated parameter |
... |
Additional graphical parameters (xlab, ylab, ...) |
No return value, called for side effects.
# mr[[i]] is a list of estimated parameters matrices (here random matrices).
# Should be mr <- multiRun(...) --> see bootstrap example in ?multiRun.
simmr_path <- system.file("extdata", "simulateMr.R", package = "morpheus")
source(simmr_path)
source(simmr_path)
mr <- simulateMr(c(2,2), 10)$mr
plotBox(mr, 2, 1) #second row, first column
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.